@@ -26,3 +26,15 @@
 extern int snek_qemu_getc(void);
 
 #define abort() exit(1)
+
+#if _PICOLIBC__ == 1 && (_PICOLIBC_MINOR__ < 6 || __PICOLIBC_PATCHLEVEL__ < 1)
+#define _SNEK_NEED_STRFROMF
+int
+strfromf(char *__restrict str, size_t n,
+	 const char *__restrict format, float fp);
+#endif
+
+#if _PICOLIBC__ == 1 && (_PICOLIBC_MINOR__ < 7 || __PICOLIBC_PATCHLEVEL__ < 5)
+#define _SNEK_NEED_STRTOF
+#endif
+
